@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
@@ -102,6 +102,10 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
                right conformation for the amino acid residue side-chain. It is adviced that
                you compare both methods when necessary.
 
+               Be mindful of the fact that FASPR may be is less flexible with reading
+               PDB files and has no mechanism to use lower conformers in the case
+               of rotamers/mutation. To avoid manual editing, pass the PDB through PRAS first.
+
     Returns
     -------
     None: repaired and hydrogenated PDB file will be written.
@@ -310,7 +314,7 @@ def repairPDB(pdb_pras,rotamer,mutation,pdb_faspr):
 
         ##################################################################################################################
         # comment next code line if you want all HIS side-chain neutral. See explanation online at www.protein-science.com
-        #check HIS protonation
+        # this code line randomly protonates 20% of all HIS residues
         res_pos, atom_name = prot_his(x,res_pos,atom_name,n)
 
         # Add backbone hydrogen.
