@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the 
+print(functionName.__doc__) to see the 
 
 documentation for the function or usage.
 
@@ -59,7 +59,7 @@ def calcDistance (m, n):
     """
     return (sqrt(sum([(m[z] - n[z])**2 for z in range(3)])))
 
-def alphahelix(lines):
+def alpha_helix(lines):
     """
     This function generates measurements required to assign alpha-helix
     
@@ -121,7 +121,7 @@ def _310helix(lines):
     hbond_distance.extend(last_three_res)
     return hbond_distance
 
-def pihelix(lines):
+def pi_helix(lines):
     """
     This function generates measurements required to assign pi-helix
     
@@ -268,7 +268,7 @@ def phiDihedral(lines):
     -------
     A list: the calculated dihedral angle
     """    
-    lines = lines[2:-3]
+    lines = lines[2:]
 
     C_list   = [l for l in lines if l[0:6] == "ATOM  " and l[13:16].strip(' ') == "C"]
     N_list   = [l for l in lines if l[0:6] == "ATOM  " and l[13:16].strip(' ') == "N"]
